summaryrefslogtreecommitdiff
path: root/drivers/staging/sm750fb/sm750.c
diff options
context:
space:
mode:
authorMike Rapoport <mike.rapoport@gmail.com>2015-10-26 10:05:55 +0300
committerGreg Kroah-Hartman <gregkh@linuxfoundation.org>2015-10-27 11:04:57 +0300
commitbc3d48f33e0a0b9f1a28d3ab06d4adc788726a9b (patch)
tree93f944be60236d6de36e46b7a75d822a721bf688 /drivers/staging/sm750fb/sm750.c
parent05407e153fce1e548fe34086057960da3d5adb53 (diff)
downloadlinux-bc3d48f33e0a0b9f1a28d3ab06d4adc788726a9b.tar.xz
staging: sm750fb: rename struct sm750_share to sm750_dev
The struct sm750_share represents the device state and name sm750_dev seems more appropriate. Signed-off-by: Mike Rapoport <mike.rapoport@gmail.com> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'drivers/staging/sm750fb/sm750.c')
-rw-r--r--drivers/staging/sm750fb/sm750.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/drivers/staging/sm750fb/sm750.c b/drivers/staging/sm750fb/sm750.c
index 6b2c4dab4055..4c689e0753df 100644
--- a/drivers/staging/sm750fb/sm750.c
+++ b/drivers/staging/sm750fb/sm750.c
@@ -650,14 +650,14 @@ static int sm750fb_set_drv(struct lynxfb_par *par)
{
int ret;
struct lynx_share *share;
- struct sm750_share *spec_share;
+ struct sm750_dev *spec_share;
struct lynxfb_output *output;
struct lynxfb_crtc *crtc;
ret = 0;
share = par->share;
- spec_share = container_of(share, struct sm750_share, share);
+ spec_share = container_of(share, struct sm750_dev, share);
output = &par->output;
crtc = &par->crtc;
@@ -937,14 +937,14 @@ exit:
/* chip specific g_option configuration routine */
static void sm750fb_setup(struct lynx_share *share, char *src)
{
- struct sm750_share *spec_share;
+ struct sm750_dev *spec_share;
char *opt;
#ifdef CAP_EXPENSION
char *exp_res;
#endif
int swap;
- spec_share = container_of(share, struct sm750_share, share);
+ spec_share = container_of(share, struct sm750_dev, share);
#ifdef CAP_EXPENSIION
exp_res = NULL;
#endif
@@ -1037,7 +1037,7 @@ static int lynxfb_pci_probe(struct pci_dev *pdev,
struct fb_info *info[] = {NULL, NULL};
struct lynx_share *share = NULL;
- struct sm750_share *spec_share = NULL;
+ struct sm750_dev *spec_share = NULL;
size_t spec_offset = 0;
int fbidx;
@@ -1048,10 +1048,10 @@ static int lynxfb_pci_probe(struct pci_dev *pdev,
}
/*
* though offset of share in sm750_share is 0,
* we use this marcro as the same
*/
- spec_offset = offsetof(struct sm750_share, share);
+ spec_offset = offsetof(struct sm750_dev, share);
spec_share = kzalloc(sizeof(*spec_share), GFP_KERNEL);
if (!spec_share) {
@@ -1202,7 +1202,7 @@ static void lynxfb_pci_remove(struct pci_dev *pdev)
iounmap(share->pvReg);
iounmap(share->pvMem);
- spec_share = container_of(share, struct sm750_share, share);
+ spec_share = container_of(share, struct sm750_dev, share);
kfree(g_settings);
kfree(spec_share);
pci_set_drvdata(pdev, NULL);
@@ -1048,10 +1048,10 @@ static int lynxfb_pci_probe(struct pci_dev *pdev,
}
/*
- * though offset of share in sm750_share is 0,
+ * though offset of share in sm750_dev is 0,
* we use this marcro as the same
*/